==> qgis-3.0.1-2-aarch64.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/i_landsat_acca.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_landsat_acca.py
    -----------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'

from .i import verifyRasterNum, orderedInput


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    return verifyRasterNum(alg, parameters, context, 'rasters', 5, 5)


def processInputs(alg, parameters, context):
    orderedInput(alg, parameters, context, 'rasters', 'input',
                 [2, 3, 4, 5, 61])


def processCommand(alg, parameters, context):
    alg.processCommand(parameters, context)

==> qgis-3.4.3-1-aarch64.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/i_landsat_acca.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    i_landsat_acca.py
    -----------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'

from .i import verifyRasterNum, orderedInput


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    return verifyRasterNum(alg, parameters, context, 'rasters', 5, 5)


def processInputs(alg, parameters, context, feedback):
    orderedInput(alg, parameters, context, 'rasters', 'input',
                 [2, 3, 4, 5, 61])


def processCommand(alg, parameters, context, feedback):
    alg.processCommand(parameters, context, feedback)
